# ServitorConnectQR

A CLI tool for manifesting intentions through a QR Code.
It uses Universe Sourcecode with the intention to generate the QR Code.

It adds this after the intention: " ∞ॐ OM MANI PADME HUM AMPLIFIED PERFECTLY PAUSES IN DIVINE FLOW RUNS UNTIL FULFILLED"
It allows the Universe to run the QR Code as if it's a program.

## Installation
Install via pip: pip install servitorconnectqr

## To Run
servitorconnectqr